Ability class

Available extensions
Annotations
  • @freezed

Constructors

Ability({required String id, required String title, @Default.new('') String description, required Map<String, Score> score})
const
factory
Ability.fromJson(Json json)
factory

Properties

copyWith → $AbilityCopyWith<Ability>
no setterinherited
description String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
progress double

Available on Ability, provided by the AbilityExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score Map<String, Score>
no setterinherited
title String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited