AssignmentStatus enum
- Inheritance
- Implemented types
- Available extensions
Values
- preparing → const AssignmentStatus
- stored → const AssignmentStatus
- categorized → const AssignmentStatus
- attached → const AssignmentStatus
- published → const AssignmentStatus
- progressing → const AssignmentStatus
- marked → const AssignmentStatus
- amending → const AssignmentStatus
- completed → const AssignmentStatus
- closed → const AssignmentStatus
- validated → const AssignmentStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AssignmentStatus> - A constant List of the values in this enum, in order of their declaration.