Message class

Available extensions
Annotations
  • @freezed

Constructors

Message({required String id, required String content, required DateTime sent, @Default.new(null) DateTime? received, @Default.new(MessageStatus.sending) MessageStatus status, required List<DateTime> statusChanges, @Default.new(null) Object? attachment})
const
factory
Message.fromJson(Json json)
factory

Properties

attachment Object?
no setterinherited
content String
no setterinherited
copyWith → $MessageCopyWith<Message>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
idFrom String

Available on Message, provided by the MessageExtension extension

no setter
idTo String

Available on Message, provided by the MessageExtension extension

no setter
received DateTime?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sent DateTime
no setterinherited
status MessageStatus
no setterinherited
statusChanges List<DateTime>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited