SchoolQualificationTaiwan enum

Inheritance
Implemented types
Available extensions

Values

elementary → const SchoolQualificationTaiwan
junior → const SchoolQualificationTaiwan
senior → const SchoolQualificationTaiwan
university → const SchoolQualificationTaiwan

Properties

grades int
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nameInMandarin String
no setter
rows List<List>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spreadsheetTable → SpreadsheetTable
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

data Map<SchoolQualificationTaiwan, List<List>>
no setter

Static Methods

parse(String string) SchoolQualificationTaiwan

Constants

values → const List<SchoolQualificationTaiwan>
A constant List of the values in this enum, in order of their declaration.