Score class
- Available extensions
- Annotations
-
- @freezed
Constructors
- Score({required double total, @Default.new(0.0) double value})
-
constfactory
- Score.fromJson(Json json)
-
factory
Properties
-
copyWith
→ $ScoreCopyWith<
Score> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- percentage → double
-
Available on Score, provided by the ScoreExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → double
-
no setterinherited
- value → double
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited