SurveyMatching class
- Annotations
-
- @freezed
Constructors
-
SurveyMatching({required String id, required String title, @Default.new('') String description, required List<
Object> questions, required List<List< sideA, required List<Object> >List< sideB, @Default.new([]) List<Object> >Map< answers})int, int> > -
constfactory
- SurveyMatching.fromJson(Json json)
-
factory
Properties
-
answers
→ List<
Map< int, int> > -
no setterinherited
-
copyWith
→ $SurveyMatchingCopyWith<
SurveyMatching> -
no setterinherited
- description → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
-
questions
→ List<
Object> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sideA
→ List<
List< Object> > -
no setterinherited
-
sideB
→ List<
List< Object> > -
no setterinherited
- title → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited